/*
 *   MediaMVP Server
 *
 *   (C) 2003 Dominic Morris
 *
 *   $Id: msgs.h,v 1.3 2004/03/16 20:07:05 dom Exp $
 *   $Date: 2004/03/16 20:07:05 $
 *
 *
 *   Definitinons of various set rfb messages
 */


/* Messages */


#ifndef __MSGS_H__
#define __MSGS_H__






/* Some sub-commands of RFB_MEDIA and RFB_MEDIA_ACK - these are used
 by the ack functions
*/
#define RDC_PLAY            0x01
#define RDC_PAUSE           0x02
#define RDC_STOP            0x03
#define RDC_REWIND          0x04
#define RDC_FORWARD         0x05
#define RDC_VOLUP           0x06
#define RDC_VOLDOWN         0x07
#define RDC_MENU            0x08          /* Used by displayon/off calls */
#define RDC_MUTE            0x09
#define RDC_SETTINGS        0x0a
#define RDC_DISPLAY_ON      0x0b          /* Fake */
#define RDC_DISPLAY_OFF     0x0c          /* Fake */

#define RDC_SKIP            0x0d          /* Fake */
#define RDC_BACK            0x0e          /* Fake */
#define RDC_SEEK_PERCENT    0x0f          /* Fake */

#define RFB_PONG            0x10          /* Fake - internal */
#define RDC_MESSAGE_MAX     0x11          /* End marker */

#define RDC_SETTINGS_GET    0x00
#define RDC_SETTINGS_TEST   0x01
#define RDC_SETTINGS_CANCEL 0x02
#define RDC_SETTINGS_SAVE   0x03






#endif
